#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_cli_app.sh
#
#   DESCRIPTION         Installer for the cli_app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2019
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#Uninstall app Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then

    systemctl disable attocliapp.service
    
    rm -f /etc/systemd/system/attocliapp.service
    rm -f /home/admin/apps/cli_app.vsn
    rm -f /home/admin/apps/cli_app.elf
    
    systemctl daemon-reload
    exit 0
  fi
fi

# untar the cli_app and its friends the cli_app into the local directory
tar -xf cli_app.tar
if [ -d /home/admin/ ]
then
   chown -R admin /home/admin/*
   chgrp -R admin /home/admin/*
fi
if [ -d /home/admin/apps/net ]
then
   chmod +x /home/admin/apps/net/*.sh
fi
if [ -d /home/admin/apps/coredump ]
then    
   chmod +x /home/admin/apps/coredump/*
fi

# make sure that core files can be generated for application space
if [ -f "/etc/security/limits.conf" ]
then
   sed -i 's/^.*core.*/\*                soft    core            8192/' /etc/security/limits.conf
else
   echo "*     soft     core     8192" > "/etc/security/limits.conf"
fi

# assume 8100T board until proven otherwise
versionjsonFile=/home/admin/apps/version.json
TTY="ttyS0"

if [ -f $versionjsonFile ]
then
   if grep -q "productid.*4e" $versionjsonFile; then
      # actually this is the devkit.
      TTY="ttyS1"
   fi
fi

# Configure a filename for cores generated by Linux (like the cli app).
# This only needs to be done once for all apps in user space,
# so we might as well do it for the CLI app. 
echo "kernel.core_pattern = /var/lib/systemd/coredump/core.%e.%t" > /usr/lib/sysctl.d/50-override.conf

# Disable and mask serial terminal service
systemctl disable serial-getty@ttyS1.service
systemctl mask serial-getty@ttyS1.service

# Disable the attocliapp service
systemctl disable attocliapp.service

# Create the service file locally, then copy to systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO CLI Console Application' >> a.sv
echo 'After=attomapping.service' >> a.sv
echo 'Requires=attomapping.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need the folowing:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=-/sbin/agetty -8 -n -l /home/admin/apps/cli_app.elf -s '$TTY' 115200' >> a.sv
echo 'Type=simple' >> a.sv # Process starts and does not exit. 
echo 'Restart=always' >> a.sv # Always, so don't forget RestartSec.
# Settings for User, StdOut/StdErr vary from service to service:
echo 'User=admin' >> a.sv
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
# Service-specific lines (if any):
# dmesg -n 1 suppresses the kernel debug, printk, from printing to the console
echo 'ExecStartPre=-/bin/dmesg -n 1' >> a.sv
echo 'ExecStartPre=/bin/sleep 3' >> a.sv
echo 'RestartSec=1' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
# Override default TimeoutStopSec of 90 seconds
echo 'TimeoutStopSec=1' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attocliapp.service ]
then
   echo "Setting reboot request flag from cli_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attocliapp.service
chmod 644 /etc/systemd/system/attocliapp.service

#
# Now reload systemd with the eventlog app
#
systemctl daemon-reload
systemctl enable attocliapp.service

