#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_eventlog.sh
#
#   DESCRIPTION         Installer for the eventlog app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2020
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#Uninstall  Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then

    systemctl disable attoeventlog.service
    
    #delete all components
    rm -f /etc/systemd/system/attoeventlog.service
    rm -f /home/admin/ftp/eventlog.txt
    rm -f /etc/attoversions/evlog_app.vsn
    rm -f /home/admin/apps/evlog_app.elf
    systemctl daemon-reload
    exit 0
  fi
fi

#  eventlog app will already be unzipped.  Create the systemd file 
#  and install it.  EventLog daemon will run automatically at next boot.
#

# Extra steps to do on a devkit once:
# vi /etc/systemd/journald.conf, uncomment SplitMode, set to none
# usermod -G admin admin
# usermod -a -G systemd-journal admin
#
# todo: this could use some error checking.

# untar the install app files.
tar -xf evlog_app.tar

# Disable the attoeventlog service
systemctl disable attoeventlog.service

# Copy logrotate.conf to /etc so our modified settings are applied
cp logrotate.conf /etc

# Create the service file locally, then copy to systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO Target Event Log Daemon' >> a.sv
echo 'After=attoinstall.service' >> a.sv
echo 'Requires=attoinstall.service' >> a.sv
echo 'Wants=network-pre.target' >> a.sv
echo 'Before=network-pre.target' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/evlog_app.elf' >> a.sv
echo 'Type=notify' >> a.sv # Doesn't exit, have to wait until the SHM is init
echo 'Restart=always' >> a.sv # Always, so don't forget RestartSec.
# Settings for User, StdIn/StdOut vary from service to service:
echo 'User=admin' >> a.sv
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
echo 'NotifyAccess=exec' >> a.sv
echo 'ExecStartPre=-/bin/touch /home/admin/ftp/eventlog.txt' >> a.sv
echo 'RestartSec=1' >> a.sv
echo 'TimeoutStartSec=200' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

# Not these for now:
#echo 'ExecStartPre=-/home/admin/apps/date/date.sh' >> a.sv
#echo 'ExecStartPre=-rm /etc/systemd/journald.conf' >> a.sv
#echo 'ExecStartPre=-cp /etc/systemd/journald.persist /etc/systemd/journald.conf' >> a.sv
#echo 'ExecStartPre=-systemctl restart systemd-journald.service' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attoeventlog.service ]
then
   echo "Setting reboot request flag from eventlog_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attoeventlog.service
chmod 644 /etc/systemd/system/attoeventlog.service

#
# Now reload systemd with the eventlog app
#
systemctl daemon-reload
systemctl enable attoeventlog.service

# Note that if there are problems with the startup of the evlog_app service,
# the following commands can be used to display what went wrong:
# journalctl -u attoeventlog.service
# systemctl status attoeventlog.service

