#!/bin/bash
#****************************************************************************
#
#   MODULE              inst_fwupdate.sh
#
#   DESCRIPTION         Installer for the firmware update app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2023
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

# The directory the fwupdate app watches for incoming ZBDs
SFTPDIR="/home/admin/sftp"

#Uninstall Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then

    systemctl disable fwupdate.service
    #delete all components
    rm -f /etc/systemd/system/attofwupdate.service
    rm -f /etc/attoversions/fwupdate_app.vsn
    rm -f /home/admin/apps/fwupdate_app.elf
    systemctl daemon-reload
    exit 0
  fi
fi

# untar the fwupdate app files.
tar -xf fwupdate_app.tar
chmod 755 fwupdate_app.elf

# Ensure the admin user's SFTP chroot jail directory exists
if [ ! -d "$SFTPDIR" ]; then
  mkdir "$SFTPDIR"
  chmod 755 "$SFTPDIR"
  chown admin:admin "$SFTPDIR"
fi

# Copy the sshd_config and sftp_banner files to /etc/ssh. There's no need to
# restart the sshd service now because at this point it's not even running.
# When it finally starts up, it will use the new values present in this
# sshd_config file. Once the rootfs is part of ZBDs, this can probably go away.
cp sshd_config /etc/ssh
cp sftp_banner /etc/ssh

#Install Requested
# Create the systemd file and install it.
# Disable the attofwupdateservice
systemctl disable attofwupdate.service

# Create the service file locally, then copy it to the systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO FW Update' >> a.sv
echo 'After=attoinitmain.service' >> a.sv
echo 'StartLimitInterval=20' >> a.sv # Must be greater than (StartLimitBurst * RestartSec)
echo 'StartLimitBurst=5' >> a.sv # Number of times the service should attempt a restart
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/fwupdate_app.elf' >> a.sv
echo 'Type=simple' >> a.sv
echo 'Restart=always' >> a.sv # Always, so don't forget RestartSec.
# Settings for User, StdOut/StdErr vary from service to service:
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
# Service-specific lines (if any):
echo 'RestartSec=3' >> a.sv # Attempt a restart every 3 seconds
echo 'LimitCORE=1048576:1048576' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attofwupdate.service ]
then
   echo "Setting reboot request flag from fwupdate_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attofwupdate.service

chmod 644 /etc/systemd/system/attofwupdate.service

#
# Now reload systemd with the fwupdate app
#
systemctl daemon-reload
systemctl enable attofwupdate.service
