#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_gui_svc.sh
#
#   DESCRIPTION         Installer for the gui service.
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2024
#   ALL RIGHTS RESERVED.
#
#*****************************************************************************

#Uninstall  Requested
if [ $# -ne 0 ]; then
    systemctl disable atto_gui.service
    #delete all components
    rm -f /etc/systemd/system/atto_gui.service
    systemctl daemon-reload
    exit 0
fi

# Create the systemd service file and install it.  The service file
# kicks off the dart web server
# /home/admin/apps/webgui/svc/main.exe

# Disable the atto gui service
systemctl disable atto_gui.service

# Create the service file locally, then copy to systemd directory.

echo '[Unit]' > a.sv
echo 'Description=Start the GUI server' >> a.sv
echo 'After=network-online.target' >> a.sv
echo 'After=attomapping.service' >> a.sv
echo 'Requires=attomapping.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps/webgui/svc' >> a.sv
echo 'ExecStart=/home/admin/apps/webgui/svc/main.exe' >> a.sv
echo 'Restart=always' >> a.sv
echo 'RestartSec=10' >> a.sv
# Settings for User, StdOut/StdErr vary from service to service:
echo 'User=admin' >> a.sv
echo 'StandardOutput=null' >> a.sv
echo 'StandardError=null' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
# Service-specific lines (if any):
echo 'TimeoutStartSec=10' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/atto_gui.service ]
then
   echo "Setting reboot request flag from gui_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/atto_gui.service
chmod 644 /etc/systemd/system/atto_gui.service

#
# Now reload systemd with the gui service
#
systemctl daemon-reload
systemctl enable atto_gui.service


