#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_initmain.sh
#
#   DESCRIPTION         Installer for the initmain app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2020
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#  initmain app will already be unzipped.  Create the systemd file 
#  and install it.  Initmain will run automatically at next boot.
#
# Extra steps to do on a devkit once:
systemctl disable connman.service
#
# todo: this could use some error checking.
#

# Disable the attoinitmain service
systemctl disable attoinitmain.service
#systemctl disable attonetworkup.service


#Uninstall Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then
    rm -f /etc/systemd/system/attoinitmain.service
    #rm -f /etc/systemd/system/attonetworkup.service
    rm -f /home/admin/apps/initmain_app.elf
    rm -f /etc/attoversions/initmain_app.vsn
    systemctl daemon-reload
    exit 0
  fi
fi 
# Note that the "ExecStartPre of a 2 second sleep is to ensure that not
# only has the evlog app started first (from the After and Requires), but 
# it's also had a chance to allocated the shared memory area before the 
# initmain app launches and also tries to init the shared memory area. 

echo '[Unit]' > a.sv
echo 'Description=ATTO Target Initalization' >> a.sv
echo 'After=attoeventlog.service' >> a.sv
echo 'Requires=attoeventlog.service' >> a.sv
echo 'Wants=network-pre.target' >> a.sv
echo 'Before=network-pre.target' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/initmain_app.elf' >> a.sv
echo 'Type=oneshot' >> a.sv # Oneshot because wait until done, does exit
echo 'Restart=no' >> a.sv
# Settings for User, StdOut/StdErr vary from service to service:
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
# Service-specific lines (if any):
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attoinitmain.service
chmod 644 /etc/systemd/system/attoinitmain.service

## Now set up the "ifup -a" script to start at boot time. 
## Only turn on StdErr for atonetworkup, because there's a lot of output.
#
echo '[Unit]' > a.sv
echo 'Description=ATTO Network Initalization' >> a.sv
echo 'After=attonetmon.service' >> a.sv
echo 'Requires=attonetmon.service' >> a.sv
echo 'Wants=network.target' >> a.sv
echo 'Before=network.target' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
echo 'StandardError=file:/var/log/adsa/AttoNetworkUpService.log' >> a.sv
echo 'StandardOutput=file:/var/log/adsa/AttoNetworkUpService.log' >> a.sv
echo 'Type=oneshot' >> a.sv # Oneshot because wait until done, does exit
echo 'Restart=no' >> a.sv
echo 'RemainAfterExit=yes' >> a.sv
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=mkdir -p /etc/network/if-up.d' >> a.sv
echo 'ExecStart=mkdir -p /etc/network/if-down.d' >> a.sv
echo 'ExecStart=-/sbin/ifup -a' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attoinitmain.service ]
then
   echo "Setting reboot request flag from initmain_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attonetworkup.service
chmod 644 /etc/systemd/system/attonetworkup.service

#
# Now reload systemd with the initmain app
#
systemctl daemon-reload
systemctl enable attoinitmain.service
systemctl enable attonetworkup.service

# Ensure that the ADSA logs folder is set up correctly and that the 
# logrotate timer is being run to keep the logs properly compressed.
mkdir -p /var/log/adsa
mkdir -p /var/log/adsa/archive
mkdir -p /var/lib/logrotate
systemctl enable --now logrotate.timer


