#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_install_app.sh
#
#   DESCRIPTION         Installer for the install app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2020 - 2023
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#Uninstall Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then
    systemctl disable attoinstall.service
    #delete all components
    rm -f /etc/systemd/system/attoinstall.service
    rm -f /etc/attoversions/install_app.vsn
    rm -f /home/admin/apps/install_app.elf
    rm -f /home/admin/apps/install_app.py
    rm -f /home/admin/apps/uninstall_app.py
    rm -f /home/admin/apps/moveSharedObjects.py
    rm -f /home/admin/apps/process_rootfs.py
    systemctl daemon-reload
    exit 0
  fi
fi

# untar the install app files.
tar -xf install_app.tar
chmod 755 install_app.elf

# Disable the attoinstall service
systemctl disable attoinstall.service

# Create the service file locally, then copy to systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO Software Installer' >> a.sv
echo 'RequiresMountsFor=/home /usr' >> a.sv
echo 'Requires=syslog.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
# Prior to running the install app, unpack the new apps.tar and put the incoming
# *.so files in /usr/lib. This ensures that any *.so files the install app uses
# (as well as any other apps that come after) are the new ones.
echo 'ExecStartPre=python3 /home/admin/apps/moveSharedObjects.py' >> a.sv
echo 'ExecStart=/home/admin/apps/install_app.elf' >> a.sv
echo 'Type=oneshot' >> a.sv
echo 'Restart=no' >> a.sv
# Settings for User, StdOut/StdErr vary from service to service:
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
# Service-specific lines (if any):
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

# Copy a.sv to the systemd directory.
mv a.sv /etc/systemd/system/attoinstall.service
chmod 644 /etc/systemd/system/attoinstall.service

systemctl enable attoinstall.service
