#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_ledmon.sh
#
#   DESCRIPTION         Installer for the ledmon app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2020
#   ALL RIGHTS RESERVED.
#
#   Arguments: -u indicates uninstall this app
#
#*****************************************************************************

#Uninstall  Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then

    systemctl disable attoledmon.service
    #delete all components
    rm -f /etc/systemd/system/attoledmon.service
    rm -f /etc/attoversions/ledmon_app.vsn
    rm -f /home/admin/apps/ledmon_app.elf
    systemctl daemon-reload
    exit 0
  fi
fi

#Install Requested
#  Create the systemd file and install it.
# Disable the attoledmon service
systemctl disable attoledmon.service

# Create the service file locally, then copy to systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO LED Monitoring' >> a.sv
echo 'After=attocliapp.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/ledmon_app.elf' >> a.sv
echo 'Type=simple' >> a.sv
echo 'Restart=always' >> a.sv # Always, so don't forget RestartSec.
# Settings for User, StdOut/StdErr vary from service to service:
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
# Service-specific lines (if any):
echo 'RestartSec=1' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attoledmon.service ]
then
   echo "Setting reboot request flag from ledmon_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attoledmon.service

chmod 644 /etc/systemd/system/attoledmon.service

#
# Now reload systemd with the ledmon app
#
systemctl daemon-reload
systemctl enable attoledmon.service





