#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_mapping.sh
#
#   DESCRIPTION         Installer for the mapping app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2020
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#Uninstall  Requested
if [ $# -ne 0 ]; then
    systemctl disable attomapping.service
    #delete all components
    rm -f /etc/systemd/system/attomapping.service
    rm -f /etc/attoversions/mapping_app.vsn
    rm -f /home/admin/apps/mapping_app.elf
    systemctl daemon-reload
    exit 0
fi

#  mapping app will already be unzipped.  Create the systemd file 
#  and install it.  The mapping app will run automatically at next boot,
#  after the network comes up, and will also be called whenever a mapping
#  change is requested.
#
# todo: this could use some error checking.
#

# Disable the attomapping service
systemctl disable attomapping.service

# Create the service file locally, then copy to systemd directory.

# Note that the "ExecStartPre of a 2 second sleep is to ensure that not
# only has the evlog app started first (from the After and Requires), but 
# it's also had a chance to allocated the shared memory area before the 
# mapping app launches and also tries to init the shared memory area. 

echo '[Unit]' > a.sv
echo 'Description=ATTO Mapping Target Initalization' >> a.sv
echo 'After=network-online.target' >> a.sv
echo 'Requires=network-online.target' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/mapping_app.elf' >> a.sv
echo 'Type=notify' >> a.sv
echo 'Restart=no' >> a.sv
# Settings for User, StdOut/StdErr vary from service to service:
echo 'User=admin' >> a.sv
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
# Service-specific lines (if any):
echo 'NotifyAccess=exec' >> a.sv
echo 'TimeoutStartSec=180' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attomapping.service ]
then
   echo "Setting reboot request flag from mapping_app installer"
   touch /var/tmp/reboot_required
fi

#
# If the connector config is missing, create a placeholder
#
if [ ! -e /etc/connconfig ]
then
   echo "Creating empty connector configuration placeholder"
   touch /etc/connconfig
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attomapping.service
chmod 644 /etc/systemd/system/attomapping.service

#
# Now reload systemd with the mapping app
#
systemctl daemon-reload
systemctl enable attomapping.service


