#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_netmon.sh
#
#   DESCRIPTION         Installer for the netmon app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2020
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#Uninstall  Requested

if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then
    systemctl disable attonetmon.service
    #delete all components
    rm -f /etc/systemd/system/attonetmon.service
    rm -f /etc/attoversions/netmon_app.vsn
    rm -f /home/admin/apps/netmon_app.elf
    systemctl daemon-reload
    exit 0
  fi
fi

#  netmon app will already be unzipped.  Create the systemd file 
#  and install it.  netmon will run automatically at next boot.

# untar the netmon app files
tar -xf netmon_app.tar

# Disable the attonetmon service
systemctl disable attonetmon.service

# Copy dhclient.conf to /etc/dhcp so our modified settings are applied
cp dhclient.conf /etc/dhcp

# Create the service file locally, then copy to systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO Network Monitoring' >> a.sv
echo 'After=attoinitmain.service' >> a.sv
echo 'Requires=attoinitmain.service' >> a.sv
echo 'Wants=network.target' >> a.sv
echo 'Before=network.target' >> a.sv
# A service unit using Restart=always enters the failed state only after the start limits are reached.
echo 'OnFailure=attoservicemon@%n.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/netmon_app.elf' >> a.sv
echo 'Type=simple' >> a.sv
echo 'Restart=always' >> a.sv # Always, so don't forget RestartSec.
# Settings for User, StdOut/StdErr vary from service to service:
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
# Service-specific lines (if any):
echo 'RestartSec=1' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attonetmon.service ]
then
   echo "Setting reboot request flag from netmon_app installer"
   touch /var/tmp/reboot_required
fi

if systemctl list-unit-files | grep masked | grep systemd-networkd; then
#
#  systemd-networkd is masked. It's needed for configuration, unmask it
#
   echo "unmasking systemd-networkd.service and setting reboot request flag"
   systemctl unmask systemd-networkd.service
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attonetmon.service
chmod 644 /etc/systemd/system/attonetmon.service

#
# Now reload systemd with the netmon app
#
systemctl daemon-reload
systemctl enable attonetmon.service
