#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_selftest.sh
#
#   DESCRIPTION         Installer for the selftest app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2020
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#  selftest app will already be unzipped.  Create the systemd file 
#  and install it.  Initmain will run automatically at next boot.
#
# todo: this could use some error checking.
#

# Disable the attoselftest service
systemctl disable attoselftest.service

#Uninstall Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then
    rm -f /etc/systemd/system/attoselftest.service
    rm -f /home/admin/apps/selftest_app.elf
    rm -f /etc/attoversions/selftest_app.vsn
    systemctl daemon-reload
    exit 0
  fi
fi 
echo '[Unit]' > a.sv
echo 'Description=ATTO Self-Test Initalization' >> a.sv
echo 'After=attoinitmain.service' >> a.sv
echo 'Requires=attoinitmain.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/selftest_app.elf' >> a.sv
echo 'Type=oneshot' >> a.sv # Oneshot because wait until done, does exit
echo 'Restart=no' >> a.sv
# Settings for User, StdOut/StdErr vary from service to service:
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
# Service-specific lines (if any):
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attoselftest.service ]
then
   echo "Setting reboot request flag from selftest_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attoselftest.service
chmod 644 /etc/systemd/system/attoselftest.service

#
# Now reload systemd with the selftest app
#
systemctl daemon-reload
systemctl enable attoselftest.service


