#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_servicemon.sh
#
#   DESCRIPTION         Installer for the servicemon app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2023
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#Uninstall  Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then
    systemctl disable attoservicemon@.service
    #delete all components
    rm -f /etc/systemd/system/attoservicemon@.service
    rm -f /etc/attoversions/servicemon_app.vsn
    rm -f /home/admin/apps/servicemon_app.elf
    systemctl daemon-reload
    exit 0
  fi
fi

#Install Requested
#  Create the systemd file and install it.

# Disable the attoservicemon@ service
systemctl stop attoservicemon@.service

# Create the service file locally, then copy to systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO Service Monitoring' >> a.sv
echo 'After=attocliapp.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need WorkingDirectory, ExecStart, Type, and Restart:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
# This service should run, fix the issue then exit 
# %i instead of %I to not escape param characters
echo 'ExecStart=/home/admin/apps/servicemon_app.elf %i' >> a.sv
echo 'Type=oneshot' >> a.sv
echo 'Restart=no' >> a.sv
# Settings for User, StdOut/StdErr vary from service to service:
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
# Service-specific lines (if any):
# echo 'RestartSec=1' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attoservicemon@.service ]
then
   echo "Setting reboot request flag from servicemon_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attoservicemon@.service
chmod 644 /etc/systemd/system/attoservicemon@.service

# We don't need to enable this at start
#systemctl enable attoservicemon@.service
